#
# Turing -- Ruby implementation of Captcha
#
# Copyright © 2005 Michal Šafránek <wejn@box.cz>
#
# This file is part of http://turing.rubyforge.org/
# and is based on PHP captcha implementation "Session captcha"
# which can be found at http://sourceforge.net/projects/session-captcha/
#
# See turing.rb in lib/ directory for license terms.
#

# == Spiral Turing test
# Renders spirals plus text over them.
class Turing::Image::Spiral < Turing::Image # {{{
	# contract method - generate the challenge
	def generate(img, word) # {{{
		fg = GD2::Color[185, 140, 140]
		sfg = GD2::Color[225, 190, 190]

		spiral(img, (img.width/3) + rand(img.width/3), rand(img.height), sfg)

		write_string(img, 'cour.ttf', fg, word)

		spiral(img, rand(img.width / 3), rand(img.height), sfg)
		spiral(img, 2*(img.width/3) + rand(img.width/3), rand(img.height), sfg)
	end # }}}

	private

	# renders spiral with center at [originx, originy] using color
	def spiral(img, originx, originy, color) # {{{
		theta = 1.0
		thetac = 6.0
		radius = 15.0
		circles = 10.0
		points = 35.0
		img.draw do |canvas|
			canvas.color = color
			0.upto(circles * points - 1) do |i|
				theta += thetac
				rad = radius * (i.to_f / points)
				x = rad * Math.cos(theta) + originx
				y = rad * Math.sin(theta) + originy
				theta += thetac
				rad1 = radius * ((i.to_f + 1.to_f) / points)
				x1 = rad1 * Math.cos(theta) + originx
				y1 = rad1 * Math.sin(theta) + originy
				canvas.line(x.round, y.round, x1.round, y1.round)
				theta -= thetac
			end
		end
	end # }}}
end # }}}

# vim: set ts=4 sw=4 :
